@@ -1,3 +1,4 @@
+from copy import deepcopy
 from datetime import datetime, timezone
 from elody.object_configurations.base_object_configuration import (
     BaseObjectConfiguration,
@@ -50,9 +51,10 @@ class ElodyConfiguration(BaseObjectConfiguration):
             post_body if isinstance(post_body, dict) else {},
         )
         _id = document_defaults.get("_id", str(uuid4()))
-        timestamp = datetime.now(timezone.utc)
 
-        identifiers = []
+        identifiers = (
+            post_body.pop("identifiers", []) if isinstance(post_body, dict) else []
+        )
         for property in self.document_info().get("identifier_properties", []):
             if identifier := flat_post_body.get(f"metadata.{property}.value"):
                 identifiers.append(identifier)
@@ -65,7 +67,6 @@ class ElodyConfiguration(BaseObjectConfiguration):
                         _id,
                         *identifiers,
                         *document_defaults.pop("identifiers", []),
-                        *post_body.pop("identifiers", []),
                     ]
                 )
             ),
@@ -85,9 +86,6 @@ class ElodyConfiguration(BaseObjectConfiguration):
             document = {**template, **document_defaults, **post_body}
         else:
             document = {**template, **document_defaults}
-        document = self._pre_crud_hook(
-            crud="create", timestamp=timestamp, document=document
-        )
         return document
 
     def _document_content_patcher(self, *, document, content, overwrite=False, **_):
@@ -106,6 +104,16 @@ class ElodyConfiguration(BaseObjectConfiguration):
                                 ):
                                     document[key].remove(item_element)
                                     break
+                    else:
+                        for value_element in value:
+                            for item_element in document[key]:
+                                if (
+                                    item_element[object_lists[key]]
+                                    == value_element[object_lists[key]]
+                                    and item_element["key"] == value_element["key"]
+                                ):
+                                    document[key].remove(item_element)
+                                    break
                     if not document.get(key):
                         document[key] = []
                     document[key].extend(value)
@@ -117,10 +125,14 @@ class ElodyConfiguration(BaseObjectConfiguration):
     def _post_crud_hook(self, **kwargs):
         pass
 
-    def _pre_crud_hook(self, *, crud, timestamp, document={}, **kwargs):
+    def _pre_crud_hook(
+        self, *, crud, timestamp, document={}, audit_override={}, **kwargs
+    ):
         if document:
             document = self.__patch_document_unique_value(document)
-            document = self.__patch_document_audit_info(crud, document, timestamp)
+            document = self.__patch_document_audit_info(
+                crud, document, timestamp, audit_override
+            )
             document = self._sanitize_document(
                 document=document,
                 object_list_name="metadata",
@@ -147,13 +159,20 @@ class ElodyConfiguration(BaseObjectConfiguration):
                 lines = value.splitlines()
                 value = "\n".join(line.strip() for line in lines).strip()
                 element[object_list_value_field_name] = value.strip()
+            for key, value in deepcopy(element).items():
+                if not value:
+                    del element[key]
         return sanitized_document
 
-    def __patch_document_audit_info(self, crud, document, timestamp):
+    def __patch_document_audit_info(self, crud, document, timestamp, audit_override):
+        if self._is_request_from_internal_service():
+            return document
+
         document.update({f"date_{crud}d": timestamp})
         if email := self._get_user_context_id():
             label = f"{crud}d_by" if crud == "create" else "last_editor"
             document.update({label: email})
+        document.update({key: value for key, value in audit_override.items() if value})
         return document
 
     def __patch_document_unique_value(self, document):
@@ -168,7 +187,45 @@ class ElodyConfiguration(BaseObjectConfiguration):
     def _sorting(self, key_order_map, **_):
         addFields, sort = {}, {}
         for key, order in key_order_map.items():
-            if key not in ["date_created", "date_updated", "last_editor"]:
+            if key == "order":
+                addFields.update(
+                    {
+                        key: {
+                            "$arrayElemAt": [
+                                {
+                                    "$map": {
+                                        "input": {
+                                            "$filter": {
+                                                "input": "$relations",
+                                                "as": "relation",
+                                                "cond": {
+                                                    "$eq": [
+                                                        {
+                                                            "$arrayElemAt": [
+                                                                "$$relation.metadata.key",
+                                                                0,
+                                                            ]
+                                                        },
+                                                        key,
+                                                    ]
+                                                },
+                                            }
+                                        },
+                                        "as": "relation",
+                                        "in": {
+                                            "$arrayElemAt": [
+                                                "$$relation.metadata.value",
+                                                0,
+                                            ]
+                                        },
+                                    }
+                                },
+                                0,
+                            ]
+                        }
+                    }
+                )
+            elif key not in ["date_created", "date_updated", "last_editor"]:
                 addFields.update(
                     {
                         key: {
@@ -185,7 +242,7 @@ class ElodyConfiguration(BaseObjectConfiguration):
                                             }
                                         },
                                         "as": "metadata",
-                                        "in": "$$metadata.value",
+                                        "in": {"$toLower": "$$metadata.value"},
                                     }
                                 },
                                 0,
