@@ -5,7 +5,7 @@ from elody.policies.permission_handler import (
     get_permissions,
     handle_single_item_request,
 )
-from flask import Request  # pyright: ignore
+from flask import g, Request  # pyright: ignore
 from inuits_policy_based_auth import BaseAuthorizationPolicy  # pyright: ignore
 from inuits_policy_based_auth.contexts.policy_context import (  # pyright: ignore
     PolicyContext,
@@ -58,7 +58,8 @@ class PostRequestRules:
         if request.method != "POST":
             return None
 
-        content = get_content(item, request, {"relations": request.json})
+        content = g.get("content") or request.json
+        content = get_content(item, request, {"relations": content})
         return handle_single_item_request(
             user_context, item, permissions, "create", content
         )
@@ -81,7 +82,8 @@ class PutRequestRules:
         if request.method != "PUT":
             return None
 
-        content = get_content(item, request, {"relations": request.json})
+        content = g.get("content") or request.json
+        content = get_content(item, request, {"relations": content})
         return handle_single_item_request(
             user_context, item, permissions, "update", content
         )
@@ -94,7 +96,8 @@ class PatchRequestRules:
         if request.method != "PATCH":
             return None
 
-        content = get_content(item, request, {"relations": request.json})
+        content = g.get("content") or request.json
+        content = get_content(item, request, {"relations": content})
         return handle_single_item_request(
             user_context, item, permissions, "update", content
         )
@@ -107,7 +110,8 @@ class DeleteRequestRules:
         if request.method != "DELETE":
             return None
 
-        content = get_content(item, request, {"relations": request.json})
+        content = g.get("content") or request.json
+        content = get_content(item, request, {"relations": content})
         return handle_single_item_request(
             user_context, item, permissions, "delete", content
         )
